# AUTOGENERATED! DO NOT EDIT! File to edit: ../notebooks/05_check-your-colorchecker.ipynb.

# %% auto 0
__all__ = ['cielab_extractor']

# %% ../notebooks/05_check-your-colorchecker.ipynb 8
from . import extract_color_patches, RGBs_to_LABs 
import pandas as pd 
import re 
import sys 
import os 

# %% ../notebooks/05_check-your-colorchecker.ipynb 9
def cielab_extractor(tif_file, write_excel=True):
    '''Extract RGB values from color patches and convert to CIELAB values table. '''  

    rectangles, RGBs = extract_color_patches(tif_file, make_plot=False) 
    LABs = RGBs_to_LABs(RGBs)

    if write_excel: 
        xlsx_file = re.sub('\.tif$', '_CIELABs.xlsx', tif_file, flags=re.IGNORECASE)
        print(f"Writing Colorchecker CIELAB values to excel file: \n'{xlsx_file}'\n")
        LABs.to_excel(xlsx_file)
    
    return LABs   

# %% ../notebooks/05_check-your-colorchecker.ipynb 10
def _console_cielab_extractor(): 
    '''Console command to extract CIELAB values.'''

    tif_file = sys.argv[-1] 

    if not os.path.exists(tif_file): 
        print(f'Error: \'{tif_file}\' does not exist. Please provide valid file path to your tif file.')
    else: 
        cielab_extractor(tif_file, write_excel=True)
        
    return 
    
